read_active_and_known_peers_at_block_hash_v2

Function read_active_and_known_peers_at_block_hash_v2 

pub(crate) fn read_active_and_known_peers_at_block_hash_v2(
    node: &TempoFullNode,
    known: &Set<PublicKey>,
    hash: B256,
) -> Result<Map<PublicKey, Address>>
Returns active validator config v2 entries at block hash.

This returns both the validators that are active as per the contract, and those that are known.